fn share_verifies(common: &AvidmGf2Common, share: &AvidmGf2Share) -> boolExpand description
Whether share verifies against a common already known to be hash-bound
to the commitment (a verify_with_verified_common success).
fn share_verifies(common: &AvidmGf2Common, share: &AvidmGf2Share) -> boolWhether share verifies against a common already known to be hash-bound
to the commitment (a verify_with_verified_common success).